@@ -28,5 +28,5 @@ def register_dependencies() -> None:
 def _configure(binder: inject.Binder) -> None:
     file_handler_service = FileHandlerService(settings)
     serializer = FileObjectSerializer(file_handler_service)
-    binder.bind(DataLoader, DataLoader(settings))
+    binder.bind(DataLoader, DataLoader())
     binder.bind(PersistenceService, PersistenceService(serializer))
