@@ -19,7 +19,7 @@ from fastapi.responses import JSONResponse
 from sentry_sdk import capture_exception, set_context
 
 from superlinked.framework.common.exception import InternalException
-from superlinked.framework.common.telemetry.telemetry_registry import telemetry
+from superlinked.framework.common.telemetry.telemetry_registry import TelemetryAttributeType, telemetry
 
 logger = structlog.getLogger(__name__)
 
@@ -71,5 +71,8 @@ def _record_exception(exception: Exception, external: bool, context: Mapping[str
             set_context("exception_context", dict(context))
         capture_exception(exception)
     metric_suffix = "external" if external else "internal"
-    labels = {"exception_type": type(exception).__name__, "exception_message": str(exception), "context": context}
+    labels: dict[str, TelemetryAttributeType] = {
+        "exception_type": type(exception).__name__,
+        "exception_message": str(exception),
+    }
     telemetry.record_metric(f"exception.{metric_suffix}", 1, labels)
